@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -84,7 +84,7 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 #define QSYNTH_CHORUS_SPEED_SCALE   100.0f
 #define QSYNTH_CHORUS_DEPTH_SCALE   10.0f
 
-#if defined(WIN32)
+#if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 #undef HAVE_SIGNAL_H
 #else
 #include <unistd.h>
@@ -208,11 +208,10 @@ static void qsynth_midi_event ( qsynthEngine *pEngine,
 					iCC == QSYNTH_MIDI_CC_BANK_SELECT_LSB ||
 					iCC >= QSYNTH_MIDI_CC_ALL_SOUND_OFF)
 					break;
-				// Fall thru...
-			}
+			}	// Fall thru...
 			case QSYNTH_MIDI_PROGRAM_CHANGE:
 				g_pMidiChannels[iChan].iChange++;
-				// Fall thru, again...
+				// Fall thru...
 			case QSYNTH_MIDI_NOTE_ON:
 			case QSYNTH_MIDI_NOTE_OFF:
 				g_pMidiChannels[iChan].iEvent++;
@@ -619,7 +618,7 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 	// Knobs
 	updateKnobs();
 
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	// Check if we can redirect our own stdout/stderr...
 	if (m_pOptions->bStdoutCapture && ::pipe(g_fdStdout) == 0) {
 		::dup2(g_fdStdout[QSYNTH_FDWRITE], STDOUT_FILENO);
@@ -747,7 +746,7 @@ bool qsynthMainForm::queryClose (void)
 				m_pMessagesForm->close();
 			if (m_pChannelsForm)
 				m_pChannelsForm->close();
-		#ifdef CONFIG_SYSTEM_TRAY
+		#if 0//CONFIG_SYSTEM_TRAY_0
 			// And the system tray icon too.
 			if (m_pSystemTray)
 				m_pSystemTray->close();
@@ -899,7 +898,7 @@ void qsynthMainForm::dropEvent ( QDropEvent* pDropEvent )
 // Set stdout/stderr blocking mode.
 bool qsynthMainForm::stdoutBlock ( int fd, bool bBlock ) const
 {
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	const int iFlags = ::fcntl(fd, F_GETFL, 0);
 	const bool bNonBlock = bool(iFlags & O_NONBLOCK);
 	if (bBlock && bNonBlock)
@@ -915,7 +914,7 @@ bool qsynthMainForm::stdoutBlock ( int fd, bool bBlock ) const
 // Own stdout/stderr socket notifier slot.
 void qsynthMainForm::stdoutNotifySlot ( int fd )
 {
- #if !defined(WIN32)
+ #if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	// Set non-blocking reads, if not already...
 	const bool bBlock = stdoutBlock(fd, false);
 	// Read as much as is available...
