@@ -71,7 +71,7 @@ void qsynthOptions::loadOptions (void)
 	bStdoutCapture  = m_settings.value("/StdoutCapture", true).toBool();
 	bOutputMeters   = m_settings.value("/OutputMeters", false).toBool();
 	bSystemTray     = m_settings.value("/SystemTray", false).toBool();
-	bSystemTrayQueryClose = m_settings.value("/SystemTrayQueryClsoe", true).toBool();
+	bSystemTrayQueryClose = m_settings.value("/SystemTrayQueryClose", true).toBool();
 	bStartMinimized = m_settings.value("/StartMinimized", false).toBool();
 	iBaseFontSize   = m_settings.value("/BaseFontSize", 0).toInt();
 	iKnobStyle      = m_settings.value("/KnobStyle", 0).toInt();
@@ -479,7 +479,7 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	m_settings.beginGroup("/Settings");
 	pSetup->sDisplayName     = m_settings.value("/DisplayName", sDisplayName).toString();
 	pSetup->bMidiIn          = m_settings.value("/MidiIn", true).toBool();
-#if defined(WIN32)
+#if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "winmidi").toString();
 	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "dsound").toString();
 	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 512).toInt();
