@@ -1,7 +1,7 @@
 // qsynthSystemTray.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -92,6 +92,10 @@ void qsynthSystemTray::activated ( QSystemTrayIcon::ActivationReason reason )
 
 void qsynthSystemTray::contextMenuRequested (void)
 {
+	// Don't show dummy menu box, ever...
+	if (qobject_cast<QMenu *> (sender()) == &m_menu)
+		m_menu.hide();
+
 	emit contextMenuRequested(QCursor::pos());
 }
 
